Name: nodejs
Version: 12.16.3
Release: 1.0.1%{?dist}
Summary: JavaScript runtime
License: MIT and ASL 2.0 and ISC and BSD
Group: Development/Languages
URL: http://nodejs.org

# Exclusive archs must match v8
ExclusiveArch: %{ix86} x86_64 

#For NodeSource, we use the sources direct from nodejs.org/dist
Source0: node-v%{version}.tar.gz
Source1: etc-profiled-nodejs.sh
Source2: etc-profiled-nodejs.csh

#Patch1: 0001-Disable-running-gyp-on-shared-deps.patch  
Patch2: 0002-Suppress-NPM-message-to-run-global-update.patch
#Patch1: nodejs-disable-gyp-deps.patch
#Patch2: nodejs-use-system-certs.patch


BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-buildroot
BuildArch: %{_target_cpu}
BuildRequires: scl-utils
BuildRequires: python2
BuildRequires: devtoolset-7-gcc >= 6.7
BuildRequires: devtoolset-7-gcc-c++ >= 6.7

#this corresponds to the "engine" requirement in package.json
Provides: nodejs(engine) = %{version}

# Node.js currently has a conflict with the 'nodejs' package in Fedora
Conflicts: nodejs

# The ham-radio group has agreed to rename their binary for us, but
# in the meantime, we're setting an explicit Conflicts: here
Conflicts: node < %{version} 

%description
Node.js is a platform built on Chrome\'s JavaScript runtime
for easily building fast, scalable network applications.
Node.js uses an event-driven, non-blocking I/O model that
makes it lightweight and efficient, perfect for data-intensive
real-time applications that run across distributed devices.

%package devel
Summary: JavaScript runtime - development headers
Group: Development/Languages
Requires: %{name}%{?_isa} == %{version}-%{release}
#Requires: nodejs-packaging

%description devel
Development headers for the Node.js JavaScript runtime.

%package docs
Summary: Node.js API documentation
Group: Documentation
BuildArch: noarch

%description docs
The API documentation for the Node.js JavaScript runtime.


%prep
%setup -q -n node-v%{version}


# remove bundled dependencies that we aren't building
#%patch1 -p1
#rm -rf deps/zlib deps/uv

# disable NPM to run glabal update.
%patch2 -p1

# remove bundled CA certificates
#%patch2 -p1
#rm -f src/node_root_certs.h

%build
export CFLAGS='%{optflags} -g -D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64'
export CXXFLAGS='%{optflags} -g -D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64'

. /opt/rh/devtoolset-7/enable
./configure --prefix=%{_prefix} \
           --without-dtrace 

# Setting BUILDTYPE=Debug builds both release and debug binaries
make BUILDTYPE=Debug %{?_smp_mflags}

%pre
if [ -d /usr/lib/node_modules/npm ]; then
  echo "Detected old npm client, removing..."
  rm -rf /usr/lib/node_modules/npm
fi

%install
rm -rf %{buildroot}
export DONT_STRIP=1  # Don't strip debug symbols for now.
. /opt/rh/devtoolset-7/enable

make install DESTDIR=%{buildroot}

# and remove dtrace file again
rm -rf %{buildroot}/%{_prefix}/lib/dtrace

# own the sitelib directory
mkdir -p %{buildroot}%{_prefix}/lib/node_modules

#node-gyp needs common.gypi too
mkdir -p %{buildroot}%{_datadir}/node
cp -p common.gypi %{buildroot}%{_datadir}/node

mkdir -p %{buildroot}/etc/profile.d/
install -m 0755 %{SOURCE1} %{buildroot}/etc/profile.d/nodejs.sh
install -m 0755 %{SOURCE2} %{buildroot}/etc/profile.d/nodejs.csh

# Set the binary permissions properly
chmod 0755 %{buildroot}/%{_bindir}/node
chmod 0755 %{buildroot}/%{_bindir}/npm

# Install the debug binary and set its permissions
install -Dpm0755 out/Debug/node %{buildroot}/%{_bindir}/node_g

#install documentation
mkdir -p %{buildroot}%{_defaultdocdir}/%{name}-%{version}/html
cp -pr doc/* %{buildroot}%{_defaultdocdir}/%{name}-%{version}/html
rm -f %{_defaultdocdir}/%{name}-%{version}/html/nodejs.1
 
# Node tries to install some python files into a documentation directory
# (and not the proper one). Remove them for now until we figure out what to
# do with them.
rm -f %{buildroot}/%{_defaultdocdir}/node/lldb_commands.py* \
%{buildroot}/%{_defaultdocdir}/node/lldbinit

# Remove junk files from node_modules/ - we should probably take care of
# this in the installer.
for FILE in .gitmodules .gitignore .npmignore .travis.yml \*.py[co]; do
    find %{buildroot}/usr/lib/node_modules/ -name "$FILE" -delete
done


%files
%doc AUTHORS BUILDING.md CHANGELOG.md CONTRIBUTING.md GOVERNANCE.md LICENSE README.md CODE_OF_CONDUCT.md SECURITY.md onboarding.md
%{_bindir}/node
%{_bindir}/npm
%{_bindir}/npx
/etc/profile.d/*
%dir %{_prefix}/lib/node_modules
%{_prefix}/lib/node_modules/*
%{_mandir}/man1/node.*
%dir %{_datadir}/node
%dir %{_datadir}/systemtap
%dir %{_datadir}/systemtap/tapset
%{_datadir}/systemtap/tapset/node.stp

%files devel
%{_bindir}/node_g
%{_includedir}/node
%{_datadir}/node/common.gypi
%{_docdir}/node/gdbinit

%files docs
%{_defaultdocdir}/%{name}-%{version}

%changelog
* Mon May 18 2020 EL Errata <el-errata_ww@oracle.com> - 12.16.3-1.0.1.el7.nodepath
- update to 12.16.3

* Mon Mar 2 2020 Qing Lin <qing.lin@oracle.com> - 12.16.1-1.el7.nodepath
- update to 12.16.1

* Tue Jan 14 2020 Qing Lin <qing.lin@oracle.com> - 12.4.0-1.0.1.el7.nodepath
- update to 10.4.0

* Tue Dec 17 2019 Jacob Wang <jacob.wang@oracle.com> - 10.18.0-1.0.1.el7.nodepath
- update to 10.18.0

* Tue Oct 22 2019 Jacob Wang <jacob.wang@oracle.com> - 10.17.0-1.0.1.el7.nodepath
- update to 10.17.0

* Thu Aug 15 2019 Jacob Wang <jacob.wang@oracle.com> - 10.16.3-1.0.1.el7.nodepath
- update to 10.16.3

* Tue Aug 6 2019 Jacob Wang <jacob.wang@oracle.com> - 10.16.2-1.0.1.el7.nodepath
- update to 10.16.2

* Wed Jul 31 2019 Jacob Wang <jacob.wang@oracle.com> - 10.16.1-1.0.1.el7.nodepath
- update to 10.16.1

* Tue May 28 2019 Jacob Wang <jacob.wang@oracle.com> - 10.16.0-1.0.1.el7.nodepath
- update to 10.16.0

* Tue Mar 5 2019 Jacob Wang <jacob.wang@oracle.com> - 10.15.3-1.0.1.el7.nodepath
- update to 10.15.3

* Thu Feb 28 2019 Jacob Wang <jacob.wang@oracle.com> - 10.15.2-1.0.1.el7.nodepath
- update to 10.15.2

* Tue Jan 29 2019 Jacob Wang <jacob.wang@oracle.com> - 10.15.1-1.0.1.el7.nodepath
- build with python27 and devtoolset-3
- update to 10.15.1

* Wed Dec 26 2018 Jacob Wang <jacob.wang@oracle.com> - 10.15.0-1.0.1.el7.nodepath
- update to 10.15.0

* Tue Dec 11 2018 Jacob Wang <jacob.wang@oracle.com> - 10.14.2-1.el7.nodepath
- update to 10.14.2

* Thu Nov 29 2018 Jacob Wang <jacob.wang@oracle.com> - 10.14.1-1.el7.nodepath
- update to 10.14.1

* Tue Nov 27 2018 Jacob Wang <jacob.wang@oracle.com> - 10.14.0-1.el7.nodepath
- update to 10.14.0

* Wed Oct 31 2018 Jacob Wang <jacob.wang@oracle.com> - 10.13.0-1.el7.nodepath
- update to 10.13.0

* Wed Oct 10 2018 Jacob Wang <jacob.wang@oracle.com> - 10.12.0-1.el7.nodepath
- update to 10.12.0

* Thu Sep 20 2018 Jacob Wang <jacob.wang@oracle.com> - 10.11.0-1.el7.nodepath
- update to 10.11.0

* Fri Sep 7 2018 Jacob Wang <jacob.wang@oracle.com> - 10.10.0-1.el7.nodepath
- update to 10.10.0

* Wed Aug 15 2018 Jacob Wang <jacob.wang@oracle.com> - 10.9.0-1.el7.nodepath
- update to 10.9.0

* Fri Aug 3 2018 Jacob Wang <jacob.wang@oracle.com> - 10.8.0-1.el7.nodepath
- update to 10.8.0

* Thu Jul 19 2018 Qing Lin <qing.lin@oracle.com> - 10.4.1-1.el7
- Upgrade to Nodejs10

* Thu Mar 1 2018 Qing Lin <qing.lin@oracle.com> - 8.9.4-2.el7
- Add NODE_PATH support.

* Thu Jan 4 2018 Jacob Wang <jacob.wang@oracle.com> - 8.9.4-1.el7
- update to 8.9.4

* Wed Dec 13 2017 Keshav Sharma <keshav.sharma@oracle.com> - 8.9.3-1.el7
- update to 8.1.4

* Fri Jul 14 2017 Keshav Sharma <keshav.sharma@oracle.com> - 8.1.4-1.el7
- update to 8.1.4

* Mon Jun 12 2017 Keshav Sharma <keshav.sharma@oracle.com> - 8.1.0-1.el7
- update to 8.1.0

* Thu Jun 8 2017 Jacob Wang <jacob.wang@oracle.com> - 6.11.0-1.el7
- update to 6.11.0

* Thu May 4 2017 Jacob Wang <jacob.wang@oracle.com> - 6.10.3-1.el7
- update to 6.10.3
- 6.10.3 version re-writes the code of using SSL certificates, so nodejs-use-system-certs.patch
  can no longer patch to it. Nodejs will now load server certificates automatically.
  (Lans Hung <lans.hung@oracle.com>)

* Thu Apr 6 2017 Jacob Wang <jacob.wang@oracle.com> - 6.10.2-1.el7
- update to 6.10.2

* Thu Mar 23 2017 Jacob Wang <jacob.wang@oracle.com> - 6.10.1-1.el7
- update to 6.10.1

* Thu Feb 23 2017 Jacob Wang <jacob.wang@oracle.com> - 6.10.0-1.el7
- update to 6.10.0

* Thu Feb 2 2017 Jacob Wang <jacob.wang@oracle.com> - 6.9.5-1.el7
- update to 6.9.5

* Thu Jan 12 2017 Jacob Wang <jacob.wang@oracle.com> - 6.9.4-1.el7
- update to 6.9.4

* Thu Jan 5 2017 Jacob Wang <jacob.wang@oracle.com> - 6.9.3-1.el7
- update to 6.9.3

* Thu Dec 8 2016 Jacob Wang <jacob.wang@oracle.com> - 6.9.2-1.el7
- update to 6.9.2

* Wed Nov 16 2016 Jacob Wang <jacob.wang@oracle.com> - 6.9.1-1.el7
- update to 6.9.1

* Wed Aug 03 2016 Keshav Sharma <keshav.sharma@oracle.com> - 6.3.1-1
- Updated to upstream version 6.3.1

* Thu Jun 02 2016 Chris Lea <chl@nodesource.com> - 6.2.1
- https://nodejs.org/en/blog/release/v6.2.1/

* Tue May 17 2016 Chris Lea <chl@nodesource.com> - 6.2.0
- https://nodejs.org/en/blog/release/v6.2.0/

* Thu May 05 2016 Chris lea <chl@nodesource.com> - 6.1.0
- https://nodejs.org/en/blog/release/v6.1.0/

* Wed Apr 27 2016 Chris Lea <chl@nodesource.com> - 6.0.0
- https://nodejs.org/en/blog/release/v6.0.0/

* Sat Apr 23 2016 Chris Lea <chl@nodesource.com> - 5.11.0
- https://nodejs.org/en/blog/release/v5.11.0/

* Tue Apr 05 2016 Chris Lea <chl@nodesource.com> - 5.10.1
- https://nodejs.org/en/blog/release/v5.10.1/

* Thu Mar 31 2016 Chris Lea <chl@nodesource.com> - 5.10.0
- https://nodejs.org/en/blog/release/v5.10.0/

* Thu Mar 24 2016 Chris Lea <chl@nodesource.com> - 5.9.1
- https://nodejs.org/en/blog/release/v5.9.1/

* Wed Mar 16 2016 Chris Lea <chl@nodesource.com> - 5.9.0
- https://nodejs.org/en/blog/release/v5.9.0/

* Thu Mar 10 2016 Chris Lea <chl@nodesource.com> - 5.8.0
- https://nodejs.org/en/blog/release/v5.8.0/

* Wed Mar 02 2016 Chris Lea <chl@nodesource.com> - 5.7.1
- https://nodejs.org/en/blog/release/v5.7.1/

* Mon Feb 22 2016 Chris Lea <chl@nodesource.com> - 5.7.0
- https://nodejs.org/en/blog/release/v5.7.0/

* Tue Feb 09 2016 Chris Lea <chl@nodesource.com> - 5.6.0
- https://nodejs.org/en/blog/release/v5.6.0/

* Tue Jan 26 2016 Chris Lea <chl@nodesource.com> - 5.5.0
- Build for RHEL6 / CentOS6.

* Thu Jan 21 2016 Chris Lea <chl@nodesource.com> - 5.5.0
- https://nodejs.org/en/blog/release/v5.5.0/

* Tue Jan 12 2016 Chris Lea <chl@nodesource.com> - 5.4.1
- https://nodejs.org/en/blog/release/v5.4.1/

* Wed Jan 06 2016 Chris Lea <chl@nodesource.com> - 5.4.0
- https://nodejs.org/en/blog/release/v5.4.0/

* Wed Dec 16 2015 Chris Lea <chl@nodesource.com> - 5.3.0
- https://nodejs.org/en/blog/release/v5.3.0/

* Wed Dec 09 2015 Chris Lea <chl@nodesource.com> - 5.2.0
- https://nodejs.org/en/blog/release/v5.2.0/

* Thu Dec 03 2015 Chris Lea <chl@nodesource.com> - 5.1.1
- https://nodejs.org/en/blog/release/v5.1.1/

* Tue Nov 17 2015 Chris Lea <chl@nodesource.com> - 5.1.0
- Statically compile in ICU, do not depend on system libs.

* Tue Nov 17 2015 Chris Lea <chl@nodesource.com> - 5.1.0
- Update to 5.1.0.
- https://nodejs.org/en/blog/release/v5.1.0/

* Thu Nov 12 2015 Chris Lea <chl@nodesource.com> - 5.0.0
- Compile with --with-intl=system-icu
- Add dependency on libicu.

* Thu Oct 29 2015 Chris Lea <chl@nodesource.com> - 5.0.0
- Update to 5.0.0.
- https://nodejs.org/en/blog/release/v5.0.0/

* Tue Oct 13 2015 Chris Lea <chl@nodesource.com> - 4.2.1
- Update to 4.2.1.
